TenBottomBar class

Inheritance
Available extensions

Constructors

TenBottomBar({Key? key, required Widget child})
const

Properties

child Widget
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onClick(GestureTapCallback func, {HitTestBehavior? behavior}) Widget

Available on Widget, provided by the WidgetCommonExtension extension

给任意部件一个点击事件
onLongPress(GestureTapCallback func, {HitTestBehavior? behavior}) Widget

Available on Widget, provided by the WidgetCommonExtension extension

给任意部件一个长按事件
paddingAll(double value) Widget

Available on Widget, provided by the WidgetCommonExtension extension

paddingOnly({double left = 0, double right = 0, double top = 0, double bottom = 0}) Widget

Available on Widget, provided by the WidgetCommonExtension extension

paddingSymmetric({double horizontal = 0, double vertical = 0}) Widget

Available on Widget, provided by the WidgetCommonExtension extension

scrollView({ScrollPhysics? physics}) Widget

Available on Widget, provided by the WidgetCommonExtension extension

让一个部件变为可滑动,使用SingleChildScrollView包裹仅此而已
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
withLoading(bool isLoading, {double size = 16, Color color = const Color(0xff027DFD)}) Widget

Available on Widget, provided by the WidgetCommonExtension extension

让部件进入加载状态

Operators

operator ==(Object other) bool
The equality operator.
inherited