TenDialog class

Constructors

TenDialog()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show(BuildContext ctx, {String confirmText = '好的', String? content, Widget? contentBuild, String? title, Widget? titleBuild, String? cancelText, Color? confirmTextColor, bool canClose = false}) Future<bool>
canClose 仅表示是否拦截系统返回意图,不代表遮罩区 return true - confirm false - cancel;