TenButtonSheet class

Constructors

TenButtonSheet()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show<T>(BuildContext context, {required Widget child, bool isScrollControlled = true, bool isDismissible = true, EdgeInsetsGeometry? padding, bool showBar = true}) Future<T?>
初始弹出窗口 使用 await show 接收 Navigator.of(context).pop(T) 的内容,建议声明 T 的类型