TenScheme class interface
final isDarkMode = Theme.of(context).brightness == Brightness.dark;
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- brandAccentColor ↔ Color
-
品牌点缀色
getter/setter pair
- error ↔ Color
-
getter/setter pair
- errorBackGroud ↔ Color
-
getter/setter pair
- linkDarkColor ↔ Color
-
链接深色
getter/setter pair
- linkLightColor ↔ Color
-
链接亮色
getter/setter pair
- maskColor ↔ Color
-
蒙层
getter/setter pair
- success ↔ Color
-
getter/setter pair
- successBackGroud ↔ Color
-
getter/setter pair
- wraning ↔ Color
-
getter/setter pair
- wraningBackGroud ↔ Color
-
getter/setter pair
Static Methods
-
getContainerBackGround(
bool isDarkMode) → Color - 返回一般容器的背景色 , miniInput 、 tabs
-
getDisable(
bool isDarkMode) → Color - 禁用色
-
getDivider(
bool isDarkMode) → Color - 返回分割线颜色
-
getOnPrimary(
bool isDarkMode) → Color - 取主题反色
-
getPopupBackGround(
bool isDarkMode) → Color - 返回Popup背景颜色 它的遮罩为 maskColor
-
getPrimary(
bool isDarkMode) → Color - 返回主题颜色
-
getSecond(
bool isDarkMode) → Color - 次要的,现在被用在表示无效文字