TenButton class
虽然继承自StatefulWidget,但实际运行效率比 InkWell 高,移除波纹效果,状态只有一次UI重绘
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- TenButton
- Available extensions
Constructors
- TenButton({required Widget child, GestureTapCallback? onTap, GestureLongPressCallback? onLongPress, Color? backgorundColor, bool isBorder = false, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 24, vertical: 12), double borderRadius = 32, double opacity = 0.85, Key? key})
-
const
- TenButton.border({required Widget child, GestureTapCallback? onTap, GestureLongPressCallback? onLongPress, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 24, vertical: 12), Key? key, double borderRadius = 32, Color? backgorundColor})
-
const
- TenButton.error({required Widget child, GestureTapCallback? onTap, GestureLongPressCallback? onLongPress, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 24, vertical: 12), Key? key, bool isBorder = false, double opacity = 0.85, double borderRadius = 32})
- TenButton.success({required Widget child, GestureTapCallback? onTap, GestureLongPressCallback? onLongPress, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 24, vertical: 12), Key? key, bool isBorder = false, double opacity = 0.85, double borderRadius = 32})
- TenButton.wraning({required Widget child, GestureTapCallback? onTap, GestureLongPressCallback? onLongPress, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 24, vertical: 12), Key? key, bool isBorder = false, double opacity = 0.85, double borderRadius = 32})
Properties
- backgorundColor → Color?
-
final
- borderRadius → double
-
final
- child → Widget
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBorder → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onLongPress → GestureLongPressCallback?
-
final
- onTap → GestureTapCallback?
-
final
- opacity → double
-
final
- padding → EdgeInsetsGeometry
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< TenButton> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onClick(
GestureTapCallback func, {HitTestBehavior? behavior}) → Widget -
Available on Widget, provided by the WidgetCommonExtension extension
给任意部件一个点击事件 -
onLongPress(
GestureTapCallback func, {HitTestBehavior? behavior}) → Widget -
Available on Widget, provided by the WidgetCommonExtension extension
给任意部件一个长按事件 -
paddingAll(
double value) → Widget -
Available on Widget, provided by the WidgetCommonExtension extension
-
paddingOnly(
{double left = 0, double right = 0, double top = 0, double bottom = 0}) → Widget -
Available on Widget, provided by the WidgetCommonExtension extension
-
paddingSymmetric(
{double horizontal = 0, double vertical = 0}) → Widget -
Available on Widget, provided by the WidgetCommonExtension extension
-
scrollView(
{ScrollPhysics? physics}) → Widget -
Available on Widget, provided by the WidgetCommonExtension extension
让一个部件变为可滑动,使用SingleChildScrollView包裹仅此而已 -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
withLoading(
bool isLoading, {double size = 16, Color color = const Color(0xff027DFD)}) → Widget -
Available on Widget, provided by the WidgetCommonExtension extension
让部件进入加载状态
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited