TenTextStyles class interface

Constructors

TenTextStyles()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

action TextStyle
getter/setter pair
actionL TextStyle
getter/setter pair
actionM TextStyle
getter/setter pair
actionS TextStyle
getter/setter pair
desction TextStyle
getter/setter pair
h1 TextStyle
getter/setter pair
h2 TextStyle
getter/setter pair
h3 TextStyle
getter/setter pair
h4 TextStyle
getter/setter pair